/** \file cameralistfile.cpp
 *  \brief This file contains the implementation of the CameraListFile class.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
 *        and the following disclaimer in the documentation and/or other materials provided with the
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "cameralistfile.h"

#include <QFile>
#include <QTextStream>
#include <QStringList>

#define MAX_LINE_LENGTH 4096

CameraListFile::CameraListFile()
{
}

CameraListFile::~CameraListFile()
{
    if( m_bOpen)
    {
        close();
    }
}

bool CameraListFile::open(QString strFilename)
{
    m_strFileName = strFilename;
    m_mapList.clear();
    m_bOpen = true;

    QFile file(strFilename);

    if( file.exists() )
    {
        if(!file.open(QIODevice::ReadOnly))
        {
            return false;
        }
        QTextStream stream(&file);
        QString strLine = stream.readLine(MAX_LINE_LENGTH);
        while( !strLine.isNull() )
        {
            if(strLine.left(4) == "cam:")
            {
                const QChar sep = ';';
                QStringList strSplittedLine = strLine.right(strLine.length()-4).split( sep, QString::SkipEmptyParts, Qt::CaseInsensitive );
                camera_list_entry new_entry;

                foreach( QString token, strSplittedLine )
                {
                    if(token.left(5) == "guid:")
                    {
                        new_entry.nGuid = token.right(token.length()-5).toULongLong();
                    }
                    else if(token.left(5) == "name:")
                    {
                        new_entry.strName = token.right(token.length()-5);
                    }
                    else if(token.left(7) == "locked:")
                    {
                        new_entry.bLocked = token.right(token.length()-7)=="yes";
                    }
                    else if(token.left(10) == "locked_by:")
                    {
                        new_entry.nLockingPid = token.right(token.length()-10).toLongLong();
                    }
                    else if(token.left(8) == "lock_ts:")
                    {
                        new_entry.nLock_TimeStamp = token.right(token.length()-8).toULong();
                    }
                }
                m_mapList[new_entry.nGuid] = new_entry;
            }
            strLine = stream.readLine(MAX_LINE_LENGTH);
            file.close();
        }
    }
    return true;
}

bool CameraListFile::close()
{
    if( !m_bOpen )
    {
        return true;
    }

    QFile file(m_strFileName);
    file.open(QIODevice::Truncate|QIODevice::WriteOnly);

    QTextStream stream(&file);

    foreach( camera_list_entry entry, m_mapList )
    {
        QString strLine = QString("cam:guid:%1;name:%2;locked:%3;locked_by:%4;lock_ts:%5;\n") .arg(entry.nGuid)
                                                                                            .arg(entry.strName)
                                                                                            .arg((entry.bLocked)?QString("yes"):QString("no"))
                                                                                            .arg(entry.nLockingPid)
                                                                                            .arg(entry.nLock_TimeStamp);
        stream << strLine;
    }
    file.close();
    return true;
}

