/** \file controlcontainer.h
 *  \brief This file contains the definition of the ControlContainer class.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef CONTROLCONTAINER_H
#define CONTROLCONTAINER_H

#include <QWidget>
#include <QVector>

#include "featurecontrols/abstractfeaturecontrol.h"
#include "featurecontrolfactory.h"
#include "dc1394camera.h"
#include "acquisitionthread.h"

/*
 * Container control class for feature controls derived from AbstractFeatureControl, utilizing QVBoxLayout.
 * Added controls are dynamically interconnected via signals and slots based on the names of the control
 * classes and the names of their signals and slots.
 */
class ControlContainer : public QWidget
{
Q_OBJECT
public:
    ControlContainer(QWidget *parent = 0 );

    ~ControlContainer();

    void addControl( AbstractFeatureControl* pControl );
    void addSpacerItem();
    bool addControl( QString strFeatureName );
    void setCamera( Dc1394Camera*      pCamera, 
                    AcquisitionThread* pThread );

    void setAcquisitionState( bool bActive );
    void timerEvent(QTimerEvent *event);

public slots:
    void OnCameraConfigInvalidated();
    void removeCamera();

private:
    static QVector<AbstractFeatureControl*> m_vecFeatures;
    FeatureControlFactory m_ControlFactory;
    int m_nCount;
};

#endif
