/** \file enumreference.h
 *  \brief This file contains the definition of the helper class EnumReference.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef ENUMREFERENCE_H
#define ENUMREFERENCE_H

#include <dc1394/dc1394.h>
#include <QString>

/**
 * Helper class for conversions of libdc1394 enums into strings
 */
class EnumReference{
    
    struct dc1394_mode_entry
    {
        const dc1394video_mode_t nVal;
        const char		 szModeName[32];
    };

    struct dc1394_framerate_entry
    {
        const dc1394framerate_t nVal;
        const char		szRateName[32];
    };

    struct dc1394_colorcoding_entry
    {
        const dc1394color_coding_t nVal;
        const char		szCodingName[32];
    };

    struct dc1394_feature_entry
    {
        const dc1394feature_t nVal;
        const char		szFeatureName[32];
    };

    struct dc1394_triggermode_entry
    {
        const dc1394trigger_mode_t nVal;
        const char      szModeName[32];
    };

    struct dc1394_triggersource_entry
    {
        const dc1394trigger_source_t nVal;
        const char      szSourceName[32];
    };

public:
    EnumReference();
    ~EnumReference();
    static QString LookupModeName( const dc1394video_mode_t eModeVal );
    static QString LookupFramerateName( const dc1394framerate_t eModeVal );
    static QString LookupColorCodingName( const dc1394color_coding_t eModeVal );
    static QString LookupFeatureName( const dc1394feature_t eVal );
    static QString LookupTriggerModeName( const dc1394trigger_mode_t eModeVal );
    static QString LookupTriggerSourceName( const dc1394trigger_source_t eVal );

protected:
    static const dc1394_mode_entry          m_arrModeList[];
    static const dc1394_framerate_entry     m_arrRateList[];
    static const dc1394_colorcoding_entry   m_arrCodingList[];
    static const dc1394_feature_entry       m_arrFeatureList[];
    static const dc1394_triggermode_entry   m_arrTriggermodeList[];
    static const dc1394_triggersource_entry m_arrTriggersourceList[];
};

#endif
