/** \file acquisitioncontrol.h
 *  \brief This file contains the definition of the feature control class AcquisitionControl. (freerun/multishot/singleshot/stop)
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef ACQUISITIONCONTROL_H
#define ACQUISITIONCONTROL_H

#include "abstractfeaturecontrol.h"
#include "ui_acquisitioncontrol.h"
#include "tools.h"

#include <dc1394/dc1394.h>


class AcquisitionControl : public AbstractFeatureControl, private Ui_AcquisitionControl
{
    Q_OBJECT
public:
    AcquisitionControl( QWidget* pParent );


    void pollStateFromCamera() {;}
    void setCamera( Dc1394Camera*      pCamera, 
                    AcquisitionThread* pThread );

    void setAcquisitionState( bool bActive );

private:
    void enableControls();

public slots:
    virtual void onStateChangedByTwinControl(void) { ; }
    void onFormatErrorFlagsChanged_autoconnect();

private slots:
    void onFreerunClicked(void);
    void onSingleshotClicked(void);
    void onMultishotClicked(void);
    void onStopClicked(void);

private:
    AcquisitionThread* m_pAcquisitionThread;
};

#endif // ACQUISITIONCONTROL_H
