/** \file aoicontrol.h
 *  \brief This file contains the definition of the feature control class AoiControl.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef AOICONTROL_H
#define AOICONTROL_H

#include "abstractfeaturecontrol.h"
#include "ui_aoicontrol.h"

#include <dc1394/dc1394.h>


class AoiControl : public AbstractFeatureControl, private Ui_AoiControl
{
    Q_OBJECT
public:
    AoiControl( QWidget* pParent );

    ~AoiControl();

    void setCamera( Dc1394Camera*      pCamera, 
                    AcquisitionThread* pThread );
    void pollStateFromCamera();

    virtual void setAcquisitionState( bool bActive );

public slots:
    virtual void onStateChangedByTwinControl(void);

    void onVideoModeSwitched_autoconnect();


private slots:
    void onAreaChange  ();
    void onLeftChange  ( int nValue );
    void onTopChange   ( int nValue );
    void onWidthChange ( int nValue );
    void onHeightChange( int nValue );

signals:
    void AoiChanged( void );
    void ImageSizeChanged( int nImgWidth, int nImgHeight );

private:
    void adjustSpinboxRanges();

    int m_nLeftUnit;
    int m_nTopUnit;
    int m_nWidthUnit;
    int m_nHeightUnit;
    int m_nWidthMax;
    int m_nHeightMax;

    int m_nLeft;
    int m_nTop;
    int m_nWidth;
    int m_nHeight;

};

#endif // AOICONTROL_H
