/** \file inputdebouncecontrol.h
 *  \brief This file contains the definition of the feature control class InputDebounceControl.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef INPUTDEBOUNCECONTROL_H
#define INPUTDEBOUNCECONTROL_H

#include "abstractfeaturecontrol.h"
#include "ui_inputdebouncecontrol.h"

#include <dc1394/dc1394.h>


class InputDebounceControl : public AbstractFeatureControl, private Ui_InputDebounceControl
{
    Q_OBJECT
public:
    InputDebounceControl( QWidget* pParent );

    ~InputDebounceControl();

    void setCamera( Dc1394Camera*      pCamera, 
                    AcquisitionThread* pThread );
    void pollStateFromCamera();

public slots:
    virtual void onStateChangedByTwinControl(void);

private slots:
    void onValueChange_1( int nValue );
    void onValueChange_2( int nValue );
    void onValueChange_3( int nValue );
    void onValueChange_4( int nValue );

private:
    int              m_nValue_1;
    int              m_nValue_2;
    int              m_nValue_3;
    int              m_nValue_4;
    bool             m_bInput1Supported;
    bool             m_bInput2Supported;
    bool             m_bInput3Supported;
    bool             m_bInput4Supported;
};

#endif // INPUTDEBOUNCECONTROL_H
