/** \file iocontrol.h
 *  \brief This file contains the definition of the feature control class IoControl.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef IOCONTROL_H
#define IOCONTROL_H

#include "abstractfeaturecontrol.h"
#include "ui_iocontrol.h"


class IoControl : public AbstractFeatureControl, private Ui_IoControl
{
    Q_OBJECT

public:
    IoControl( QWidget* pParent );
    ~IoControl();

    void setCamera( Dc1394Camera*      pCamera, 
                    AcquisitionThread* pThread );
    void pollStateFromCamera();

public slots:
    virtual void onStateChangedByTwinControl(void);

signals:
    void IoSettingsChange( bool bActive, int nGrabCount );

private slots:
    void onOut1StateClicked( bool bChecked );
    void onOut2StateClicked( bool bChecked );
    void onOut3StateClicked( bool bChecked );
    void onOut4StateClicked( bool bChecked );

    void onIn1PolClicked( bool bChecked );
    void onIn2PolClicked( bool bChecked );

    void onOut1PolClicked( bool bChecked );
    void onOut2PolClicked( bool bChecked );
    void onOut3PolClicked( bool bChecked );
    void onOut4PolClicked( bool bChecked );

    void onIn1ModeChange( int nIndex );
    void onIn2ModeChange( int nIndex );
    void onOut1ModeChange( int nIndex );
    void onOut2ModeChange( int nIndex );
    void onOut3ModeChange( int nIndex );
    void onOut4ModeChange( int nIndex );


private:
    void darkenCheckBox( QCheckBox* pCheckbox, bool bDarken );

    bool m_bIn1Supported, m_bIn2Supported;
    bool m_bOut1Supported, m_bOut2Supported, m_bOut3Supported, m_bOut4Supported;
    int m_nIn1Mode, m_nIn2Mode;
    int m_nOut1Mode, m_nOut2Mode, m_nOut3Mode, m_nOut4Mode;
    bool m_bIn1State, m_bIn2State;
    bool m_bOut1State, m_bOut2State, m_bOut3State, m_bOut4State;
    bool m_bIn1Pol, m_bIn2Pol;
    bool m_bOut1Pol, m_bOut2Pol, m_bOut3Pol, m_bOut4Pol;
};

#endif
