/** \file ledcontrol.cpp
 *  \brief This file contains the implementation of the feature control class LedControl.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#include "ledcontrol.h"

LedControl::LedControl( QWidget* pParent )
 : AbstractFeatureControl( pParent )
 , Ui_LedControl()
{
    setupUi ( this );

    connect( m_pEnableCheckBox, SIGNAL( clicked(bool) ), this, SLOT( onEnableClicked(bool) ) );
}


LedControl::~LedControl()
{
}


void LedControl::setCamera( Dc1394Camera*      pCamera,
                            AcquisitionThread* /*pThread*/ )
{
    m_pCamObject = pCamera;

    if( NULL == m_pCamObject )
    {
        setEnabled( false );
        return;
    }

    /* check feature support */
    if ( DC1394_FALSE == pCamera->smartFeatureInquiry()->LedBlanking )
    {
        /* mirror image feature is not supported */
        setEnabled(false);
        return;
    }

    setEnabled(true);
    pollStateFromCamera();
}


void LedControl::pollStateFromCamera()
{
    dc1394error_t eRet;
    dc1394switch_t eActive;

    eRet = dc1394_avt_get_led( m_pCamObject->psCamInternal(), &eActive );
    LOGFCALL_LIBDC ( "dc1394_avt_get_led", eRet );

    m_bActive = (DC1394_ON==eActive);

    m_pEnableCheckBox->setChecked( m_bActive );
}


void LedControl::onStateChangedByTwinControl(void)
{
    LedControl* pSender = qobject_cast<LedControl*> ( sender() );
    if( NULL == pSender )
    {
        return;
    }

    m_bActive = pSender->m_bActive;
    m_pEnableCheckBox->setChecked( m_bActive );
}


void LedControl::onEnableClicked ( bool bChecked )
{
    if( m_bActive != bChecked )
    {
        m_bActive = bChecked;

        dc1394error_t eRet;
        eRet = dc1394_avt_set_led( m_pCamObject->psCamInternal(),
                                   m_bActive? DC1394_ON : DC1394_OFF );
        LOGFCALL_LIBDC ( "dc1394_avt_set_led", eRet );

        emit featureStateChanged();
    }
}
