/** \file standardfeaturecontrol.h
 *  \brief This file contains the definition of the StandardFeatureControl class.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef STANDARDFEATURECONTROL_H
#define STANDARDFEATURECONTROL_H

#include "abstractfeaturecontrol.h"
#include "ui_standardfeaturecontrol.h"

#include <dc1394/dc1394.h>


/**
 * feature control class for all libdc standard features
 */
class StandardFeatureControl : public AbstractFeatureControl, private Ui_StandardFeatureControl
{
        Q_OBJECT

        friend class ShutterControl;

    public:
        StandardFeatureControl( QWidget* pParent, const dc1394feature_t eFeature, const QString &strName );
        virtual ~StandardFeatureControl();

        virtual void            setCamera( Dc1394Camera*      pCamera, 
                                           AcquisitionThread* pThread );
        virtual void            pollStateFromCamera();
        virtual dc1394feature_t libdcFeatureId() { return m_eFeature; }

    public slots:
        virtual void onStateChangedByTwinControl(void);

    private slots:
        void onValueChange( int nValue );
        void onEnableClicked( bool bChecked );
        void onAutoClicked( bool bChecked );
        void onOnePushClicked();

    private:
        bool             m_bCustomSizeHintActive;
        QSize            m_customSizeHint;
        int              m_nFullHeight;

        void             enableControls();

        QString          m_strName;
        dc1394feature_t  m_eFeature;
        bool             m_bAutoSupported;
        bool             m_bOnePushAutoSupported;

        bool             m_bPowerState;
        int              m_nValue;
        bool             m_bAutoActive;
};

#endif
