/** \file testimagecontrol.cpp
 *  \brief This file contains the implementation of the feature control class TestImageControl.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#include "testimagecontrol.h"

TestImageControl::TestImageControl( QWidget* pParent )
 : AbstractFeatureControl( pParent )
 , Ui_TestImageControl()
{
    setupUi ( this );

    m_pComboBox->clear();
    m_pComboBox->addItem( "Off", QVariant( 0 ) );

    connect( m_pComboBox, SIGNAL( currentIndexChanged(int) ), this, SLOT( onChange(int) ) );
}


TestImageControl::~TestImageControl()
{
}


void TestImageControl::setCamera( Dc1394Camera*      pCamera, 
                                 AcquisitionThread* /*pThread*/ )
{
    m_pCamObject = pCamera;

    if( NULL == m_pCamObject )
    {
        setEnabled( false );
        return;
    }

    /* check feature support */
    if ( DC1394_FALSE == pCamera->smartFeatureInquiry()->TestImage )
    {
        /* time base is not supported */
        setEnabled(false);
        return;
    }

    m_pComboBox->clear();
    m_pComboBox->addItem( "Off", QVariant( 0 ) );

    /* check support for each test image */
    dc1394bool_t bImg1Support, bImg2Support, bImg3Support, bImg4Support, bImg5Support, bImg6Support, bImg7Support;
    dc1394error_t eRet = dc1394_avt_get_test_images_info( pCamera->psCamInternal(),
                                                          &bImg1Support,
                                                          &bImg2Support,
                                                          &bImg3Support,
                                                          &bImg4Support,
                                                          &bImg5Support,
                                                          &bImg6Support,
                                                          &bImg7Support );
    LOGFCALL_LIBDC ( "dc1394_avt_get_test_images_info", eRet );
    if( DC1394_SUCCESS == eRet )
    {
        if(DC1394_TRUE==bImg1Support)
        {
            m_pComboBox->addItem( "Image 1", QVariant( 1 ) );
        }
        if(DC1394_TRUE==bImg2Support)
        {
            m_pComboBox->addItem( "Image 2", QVariant( 2 ) );
        }
        if(DC1394_TRUE==bImg3Support)
        {
            m_pComboBox->addItem( "Image 3", QVariant( 3 ) );
        }
        if(DC1394_TRUE==bImg4Support)
        {
            m_pComboBox->addItem( "Image 4", QVariant( 4 ) );
        }
        if(DC1394_TRUE==bImg5Support)
        {
            m_pComboBox->addItem( "Image 5", QVariant( 5 ) );
        }
        if(DC1394_TRUE==bImg6Support)
        {
            m_pComboBox->addItem( "Image 6", QVariant( 6 ) );
        }
        if(DC1394_TRUE==bImg7Support)
        {
            m_pComboBox->addItem( "Image 7", QVariant( 7 ) );
        }
    }


    setEnabled(true);
    pollStateFromCamera();
}


void TestImageControl::pollStateFromCamera()
{
    dc1394error_t eRet;
    uint32_t nVal;
    eRet = dc1394_avt_get_test_images( m_pCamObject->psCamInternal(), &nVal );
    LOGFCALL_LIBDC ( "dc1394_avt_get_test_images", eRet );

    m_nCurrentTestImage = (int) nVal;
    m_pComboBox->setCurrentIndex( m_pComboBox->findData( QVariant( m_nCurrentTestImage ) ) );
}


void TestImageControl::onStateChangedByTwinControl(void)
{
    TestImageControl* pSender = qobject_cast<TestImageControl*> ( sender() );
    if( NULL == pSender )
    {
        return;
    }

    m_nCurrentTestImage = pSender->m_nCurrentTestImage;
    m_pComboBox->setCurrentIndex( m_pComboBox->findData( QVariant( m_nCurrentTestImage ) ) );
}


void TestImageControl::onChange( int nIndex )
{
    if( nIndex != m_nCurrentTestImage )
    {
        m_nCurrentTestImage = m_pComboBox->itemData( nIndex ).toInt();

        dc1394error_t eRet;
        eRet = dc1394_avt_set_test_images( m_pCamObject->psCamInternal(), 
                                           (uint32_t) m_nCurrentTestImage );
        LOGFCALL_LIBDC ( "dc1394_avt_set_test_images", eRet );

        emit TestImageChange( m_nCurrentTestImage );
        emit featureStateChanged();
    }
}
