/** \file logger.cpp
 *  \brief This file contains the implementation of the helper class Logger.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#include "logger.h"

Logger* Logger::instance()
{
    if( NULL == m_pInstance )
    {
        m_pInstance = new Logger;
        QObject::connect(qApp, SIGNAL(lastWindowClosed()), m_pInstance, SLOT(deleteLater()));
    }
    return m_pInstance;
}

Logger::Logger():   m_bEnable(true)
                  , m_AccessMutex()
{
    m_pFile = new QTemporaryFile ( "cc1394_log.XXXXXX" );
	m_pFile->setAutoRemove ( true );
	m_pFile->open();
}


Logger::~Logger()
{
    m_pFile->close();
    delete m_pFile;
}

void Logger::log ( const QString msg, ... )
{
    if( !isEnabled() )
    {
        return;
    }

    QMutexLocker locker(&instance()->m_AccessMutex);

    const size_t BufSize = 4096;
    char buf[BufSize];

	va_list ap;
	va_start ( ap, msg );  

    ::vsnprintf ( buf, BufSize, msg.toAscii().constData() , ap );

    va_end ( ap );

    if ( file() )
	{

        file()->write ( buf, strlen(buf) );
        file()->write ( "\n", 1 );
        file()->flush();
	}

    QString strMessage( buf );
    instance()->emitLogMessage( strMessage );
}

void Logger::connectLogWindow( LogWindow* pWin )
{
    instance()->connectLogWindow_p( pWin );
}

void Logger::connectLogWindow_p( LogWindow* pWin )
{
    connect( this, SIGNAL(newLogMessage(QString)), pWin, SLOT(onLogMessage(QString)) );
}

Logger* Logger::m_pInstance = NULL;
