/** \file logger.h
 *  \brief This file contains the definition of the helper class Logger.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef LOGGER_H
#define LOGGER_H

#include <QObject>
#include <QTemporaryFile>
#include <QMutex>
#include <QMutexLocker>
#include <QList>
#include <QTextEdit>

#include "logwindow.h"

/* helper macro for libdc1394 function call logging */
#define LOGFCALL_LIBDC(func,err) \
 Logger::log("%s called: return code %u", func, (unsigned int) err); \
 if ( err != DC1394_SUCCESS ) { Logger::log("Error: %s", dc1394_error_get_string(err) ); }


/**
 * Logger class based on the singleton pattern
 */
class Logger : public QObject
{
    Q_OBJECT

    public:

        static void enable( bool bEnabled ) { instance()->m_bEnable = bEnabled; }
        static bool isEnabled() { return instance()->m_bEnable; }
        static void log ( const QString msg, ... );
        static void connectLogWindow( LogWindow* pWin );
        static QTemporaryFile* file() { return instance()->m_pFile; }

    signals:
        void newLogMessage(QString strMessage);

    private:
        static Logger* instance();

        Logger();
        ~Logger();

        void emitLogMessage( QString strMessage ){ emit newLogMessage( strMessage ); }
        void connectLogWindow_p( LogWindow* pWin );
        static Logger*  m_pInstance;

        bool            m_bEnable;
        QTemporaryFile* m_pFile;
        QMutex          m_AccessMutex;
};

#endif
