/** \file mainwindow.h
 *  \brief This file contains the definition of the MainWindow class.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QActionGroup>
#include <QList>

#include "ui_mainwindow.h"
#include "acquisitionthread.h"
#include "dc1394camera.h"
#include "controlcontainer.h"

class MainWindow : public QMainWindow, private Ui::MainWindow
{
        Q_OBJECT


    public:
        MainWindow ( QWidget* parent = 0, Qt::WFlags fl = 0 );
        ~MainWindow();

        void updateCameras();

    public slots:
        void onStatsUpdate ( double dbFramesPerSecond,
                             double dbFramesPerSecond_Displayed,
                             unsigned int nFrameCount ,
                             unsigned int nFrameCount_Displayed );
        void onAcquisitionStateChange ( bool bAcquisitionActive );

    protected:
        bool loadFeatureLayout( QString strFilename );
        void resizeEvent ( QResizeEvent * event );
        void keyPressEvent ( QKeyEvent * event );
        void timerEvent(QTimerEvent *event);

    protected slots:
        void onCameraMenuAction ( QAction* action );
        void onVideoMenuScaleAction();
        void onVideoMenuArAction();  // 'Keep Aspect Ratio' Menu Item
        void onVideoMenuFullScreenAction();
        void onControlMenuFreeRun();
        void onControlMenuSingleShot();
        void onControlMenuMultiShot();
        void onControlMenuStop();
        void onControlMenuRegisterAccess();
        void onInfoMenuDebug();
        void onInfoMenuCamInfo();
        void onHelpMenuAboutAction();

    private:
        QActionGroup*               m_pVideoSizeActions;
        QActionGroup*               m_pVideoBayerPatternActions;
        QActionGroup*               m_pVideoDebayerMethodActions;
        QList< QAction* >           m_lstCameraActions;
        AcquisitionThread*          m_pAcquisitionThread;
        Dc1394Camera*               m_pCamera;
        QList<ControlContainer*>    m_lstControlContainers;

        QLabel*                     m_pStatusLabel;
};

#endif

