/** \file registermap.cpp
 *  \brief This file contains the implementation of the helper class RegisterMap.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
 *        and the following disclaimer in the documentation and/or other materials provided with the
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "registermap.h"

RegisterMap::RegisterMap()
{
}


QMap<QString, uint32_t>* RegisterMap::pMap()
{
    initMap();
    return &m_mapRegisters;
}

uint32_t RegisterMap::rel2abs(uint32_t nAddr)
{
    if(nAddr>=0xf0000000)
    {
        return nAddr;
    }

    if(nAddr>=0x01000000)
    {
        return nAddr;
    }
    else
    {
        return (nAddr|0x00f00000);
    }
}


uint32_t RegisterMap::getAddress(QString strReg)
{
    initMap();
    if( m_mapRegisters.contains(strReg) )
    {
        return rel2abs(m_mapRegisters[strReg]);
    }
    else
    {
        return 0;
    }
}


void RegisterMap::initMap()
{
    if( m_mapRegisters.size()>0 )
    {
        return;
    }
    m_mapRegisters["INITIALIZE"] = 0x000;
    m_mapRegisters["CUR_V_FRM_RATE"] = 0x600;
    m_mapRegisters["CUR_V_MODE"] = 0x604;
    m_mapRegisters["CUR_V_FORMAT"] = 0x608;
    m_mapRegisters["ISO_CHANNEL"] = 0x60C;
    m_mapRegisters["CAMERA_POWER"] = 0x610;
    m_mapRegisters["ISO_ENABLE"] = 0x614;
    m_mapRegisters["MEMORY_SAVE"] = 0x618;
    m_mapRegisters["ONE_SHOT"] = 0x61C;
    m_mapRegisters["MEM_SAVE_CHN"] = 0x620;
    m_mapRegisters["CUR_MEM_CHN"] = 0x624;
    m_mapRegisters["VMODE_ERROR_STATUS"] = 0x628;
    m_mapRegisters["SOFTTRIGGER"] = 0x62C; // IIDC-1.31
    m_mapRegisters["DATADEPTH"] = 0x630; // IIDC-1.31

    m_mapRegisters["BRIGHTNESS"] = 0x800;
    m_mapRegisters["AUTOEXPOSURE"] = 0x804;
    m_mapRegisters["SHARPNESS"] = 0x808;
    m_mapRegisters["WHITE_BALANCE"] = 0x80C;
    m_mapRegisters["HUE"] = 0x810;
    m_mapRegisters["SATURATION"] = 0x814;
    m_mapRegisters["GAMMA"] = 0x818;
    m_mapRegisters["SHUTTER"] = 0x81C;
    m_mapRegisters["GAIN"] = 0x820;
    m_mapRegisters["IRIS"] =  0x824;
    m_mapRegisters["FOCUS"] = 0x828;
    m_mapRegisters["TEMPERATURE"] = 0x82C;
    m_mapRegisters["TRIGGER"] =  0x830;
    m_mapRegisters["TRIGGER_DLY"] = 0x834;
    m_mapRegisters["WHITE_SHD"] = 0x838;
    m_mapRegisters["FRAMERATE"] = 0x83C;
    m_mapRegisters["ZOOM"] = 0x880;
    m_mapRegisters["PAN"] = 0x884;
    m_mapRegisters["TILT"] = 0x888;
    m_mapRegisters["OPTICAL_FILTER"] = 0x88C;
    m_mapRegisters["CAPTURE_SIZE"] = 0x8C0;
    m_mapRegisters["CAPTURE_QUALITY"] = 0x8C4;

    m_mapRegisters["F7M0_MAX_IMAGE_SIZE_INQ"] = 0x8000;
    m_mapRegisters["F7M0_UNIT_SIZE_INQ"] = 0x8004;
    m_mapRegisters["F7M0_IMAGE_POSITION"] = 0x8008;
    m_mapRegisters["F7M0_IMAGE_SIZE"] = 0x800C;
    m_mapRegisters["F7M0_COLOR_CODING_ID"] = 0x8010;
    m_mapRegisters["F7M0_COLOR_CODING_INQ"] = 0x8014;
    m_mapRegisters["F7M0_PIXEL_NUMBER_INQ"] = 0x8034;
    m_mapRegisters["F7M0_TOTAL_BYTES_HI_INQ"] = 0x8038;
    m_mapRegisters["F7M0_TOTAL_BYTES_LO_INQ"] = 0x803C;
    m_mapRegisters["F7M0_PACKET_PARA_INQ"] = 0x8040;
    m_mapRegisters["F7M0_BYTE_PER_PACKET"] = 0x8044;
    m_mapRegisters["F7M0_PACKET_PER_FRAME_INQ"] = 0x8048;
    m_mapRegisters["F7M0_UNIT_POSITION_INQ"] = 0x804C;
    m_mapRegisters["F7M0_COLOR_FILTER_ID"] = 0x8058;
    m_mapRegisters["F7M0_VALUE_SETTING"] = 0x807C;

    m_mapRegisters["F7M1_MAX_IMAGE_SIZE_INQ"] = 0x9000;
    m_mapRegisters["F7M1_UNIT_SIZE_INQ"] = 0x9004;
    m_mapRegisters["F7M1_IMAGE_POSITION"] = 0x9008;
    m_mapRegisters["F7M1_IMAGE_SIZE"] = 0x900C;
    m_mapRegisters["F7M1_COLOR_CODING_ID"] = 0x9010;
    m_mapRegisters["F7M1_COLOR_CODING_INQ"] = 0x9014;
    m_mapRegisters["F7M1_PIXEL_NUMBER_INQ"] = 0x9034;
    m_mapRegisters["F7M1_TOTAL_BYTES_HI_INQ"] = 0x9038;
    m_mapRegisters["F7M1_TOTAL_BYTES_LO_INQ"] = 0x903C;
    m_mapRegisters["F7M1_PACKET_PARA_INQ"] = 0x9040;
    m_mapRegisters["F7M1_BYTE_PER_PACKET"] = 0x9044;
    m_mapRegisters["F7M1_PACKET_PER_FRAME_INQ"] = 0x9048;
    m_mapRegisters["F7M1_UNIT_POSITION_INQ"] = 0x904C;
    m_mapRegisters["F7M1_COLOR_FILTER_ID"] = 0x9058;
    m_mapRegisters["F7M1_VALUE_SETTING"] = 0x907C;

    m_mapRegisters["F7M2_MAX_IMAGE_SIZE_INQ"] = 0xA000;
    m_mapRegisters["F7M2_UNIT_SIZE_INQ"] = 0xA004;
    m_mapRegisters["F7M2_IMAGE_POSITION"] = 0xA008;
    m_mapRegisters["F7M2_IMAGE_SIZE"] = 0xA00C;
    m_mapRegisters["F7M2_COLOR_CODING_ID"] = 0xA010;
    m_mapRegisters["F7M2_COLOR_CODING_INQ"] = 0xA014;
    m_mapRegisters["F7M2_PIXEL_NUMBER_INQ"] = 0xA034;
    m_mapRegisters["F7M2_TOTAL_BYTES_HI_INQ"] = 0xA038;
    m_mapRegisters["F7M2_TOTAL_BYTES_LO_INQ"] = 0xA03C;
    m_mapRegisters["F7M2_PACKET_PARA_INQ"] = 0xA040;
    m_mapRegisters["F7M2_BYTE_PER_PACKET"] = 0xA044;
    m_mapRegisters["F7M2_PACKET_PER_FRAME_INQ"] = 0xA048;
    m_mapRegisters["F7M2_UNIT_POSITION_INQ"] = 0xA04C;
    m_mapRegisters["F7M2_COLOR_FILTER_ID"] = 0xA058;
    m_mapRegisters["F7M2_VALUE_SETTING"] = 0xA07C;

    m_mapRegisters["F7M3_MAX_IMAGE_SIZE_INQ"] = 0xB000;
    m_mapRegisters["F7M3_UNIT_SIZE_INQ"] = 0xB004;
    m_mapRegisters["F7M3_IMAGE_POSITION"] = 0xB008;
    m_mapRegisters["F7M3_IMAGE_SIZE"] = 0xB00C;
    m_mapRegisters["F7M3_COLOR_CODING_ID"] = 0xB010;
    m_mapRegisters["F7M3_COLOR_CODING_INQ"] = 0xB014;
    m_mapRegisters["F7M3_PIXEL_NUMBER_INQ"] = 0xB034;
    m_mapRegisters["F7M3_TOTAL_BYTES_HI_INQ"] = 0xB038;
    m_mapRegisters["F7M3_TOTAL_BYTES_LO_INQ"] = 0xB03C;
    m_mapRegisters["F7M3_PACKET_PARA_INQ"] = 0xB040;
    m_mapRegisters["F7M3_BYTE_PER_PACKET"] = 0xB044;
    m_mapRegisters["F7M3_PACKET_PER_FRAME_INQ"] = 0xB048;
    m_mapRegisters["F7M3_UNIT_POSITION_INQ"] = 0xB04C;
    m_mapRegisters["F7M3_COLOR_FILTER_ID"] = 0xB058;
    m_mapRegisters["F7M3_VALUE_SETTING"] = 0xB07C;

    m_mapRegisters["F7M4_MAX_IMAGE_SIZE_INQ"] = 0xC000;
    m_mapRegisters["F7M4_UNIT_SIZE_INQ"] = 0xC004;
    m_mapRegisters["F7M4_IMAGE_POSITION"] = 0xC008;
    m_mapRegisters["F7M4_IMAGE_SIZE"] = 0xC00C;
    m_mapRegisters["F7M4_COLOR_CODING_ID"] =  0xC010;
    m_mapRegisters["F7M4_COLOR_CODING_INQ"] = 0xC014;
    m_mapRegisters["F7M4_PIXEL_NUMBER_INQ"] = 0xC034;
    m_mapRegisters["F7M4_TOTAL_BYTES_HI_INQ"] = 0xC038;
    m_mapRegisters["F7M4_TOTAL_BYTES_LO_INQ"] = 0xC03C;
    m_mapRegisters["F7M4_PACKET_PARA_INQ"] = 0xC040;
    m_mapRegisters["F7M4_BYTE_PER_PACKET"] = 0xC044;
    m_mapRegisters["F7M4_PACKET_PER_FRAME_INQ"] = 0xC048;
    m_mapRegisters["F7M4_UNIT_POSITION_INQ"] = 0xC04C;
    m_mapRegisters["F7M4_COLOR_FILTER_ID"] = 0xC058;
    m_mapRegisters["F7M4_VALUE_SETTING"] = 0xC07C;

    m_mapRegisters["F7M5_MAX_IMAGE_SIZE_INQ"] = 0xD000;
    m_mapRegisters["F7M5_UNIT_SIZE_INQ"] = 0xD004;
    m_mapRegisters["F7M5_IMAGE_POSITION"] = 0xD008;
    m_mapRegisters["F7M5_IMAGE_SIZE"] = 0xD00C;
    m_mapRegisters["F7M5_COLOR_CODING_ID"] = 0xD010;
    m_mapRegisters["F7M5_COLOR_CODING_INQ"] = 0xD014;
    m_mapRegisters["F7M5_PIXEL_NUMBER_INQ"] = 0xD034;
    m_mapRegisters["F7M5_TOTAL_BYTES_HI_INQ"] = 0xD038;
    m_mapRegisters["F7M5_TOTAL_BYTES_LO_INQ"] = 0xD03C;
    m_mapRegisters["F7M5_PACKET_PARA_INQ"] = 0xD040;
    m_mapRegisters["F7M5_BYTE_PER_PACKET"] = 0xD044;
    m_mapRegisters["F7M5_PACKET_PER_FRAME_INQ"] = 0xD048;
    m_mapRegisters["F7M5_UNIT_POSITION_INQ"] = 0xD04C;
    m_mapRegisters["F7M5_COLOR_FILTER_ID"] = 0xD058;
    m_mapRegisters["F7M5_VALUE_SETTING"] = 0xD07C;

    m_mapRegisters["F7M6_MAX_IMAGE_SIZE_INQ"] = 0xE000;
    m_mapRegisters["F7M6_UNIT_SIZE_INQ"] = 0xE004;
    m_mapRegisters["F7M6_IMAGE_POSITION"] = 0xE008;
    m_mapRegisters["F7M6_IMAGE_SIZE"] = 0xE00C;
    m_mapRegisters["F7M6_COLOR_CODING_ID"] = 0xE010;
    m_mapRegisters["F7M6_COLOR_CODING_INQ"] = 0xE014;
    m_mapRegisters["F7M6_PIXEL_NUMBER_INQ"] = 0xE034;
    m_mapRegisters["F7M6_TOTAL_BYTES_HI_INQ"] = 0xE038;
    m_mapRegisters["F7M6_TOTAL_BYTES_LO_INQ"] = 0xE03C;
    m_mapRegisters["F7M6_PACKET_PARA_INQ"] = 0xE040;
    m_mapRegisters["F7M6_BYTE_PER_PACKET"] = 0xE044;
    m_mapRegisters["F7M6_PACKET_PER_FRAME_INQ"] = 0xE048;
    m_mapRegisters["F7M6_UNIT_POSITION_INQ"] = 0xE04C;
    m_mapRegisters["F7M6_COLOR_FILTER_ID"] = 0xE058;
    m_mapRegisters["F7M6_VALUE_SETTING"] = 0xE07C;

    m_mapRegisters["F7M7_MAX_IMAGE_SIZE_INQ"] = 0xF000;
    m_mapRegisters["F7M7_UNIT_SIZE_INQ"] = 0xF004;
    m_mapRegisters["F7M7_IMAGE_POSITION"] = 0xF008;
    m_mapRegisters["F7M7_IMAGE_SIZE"] = 0xF00C;
    m_mapRegisters["F7M7_COLOR_CODING_ID"] = 0xF010;
    m_mapRegisters["F7M7_COLOR_CODING_INQ"] = 0xF014;
    m_mapRegisters["F7M7_PIXEL_NUMBER_INQ"] = 0xF034;
    m_mapRegisters["F7M7_TOTAL_BYTES_HI_INQ"] = 0xF038;
    m_mapRegisters["F7M7_TOTAL_BYTES_LO_INQ"] = 0xF03C;
    m_mapRegisters["F7M7_PACKET_PARA_INQ"] = 0xF040;
    m_mapRegisters["F7M7_BYTE_PER_PACKET"] = 0xF044;
    m_mapRegisters["F7M7_PACKET_PER_FRAME_INQ"] = 0xF048;
    m_mapRegisters["F7M7_UNIT_POSITION_INQ"] = 0xF04C;
    m_mapRegisters["F7M7_COLOR_FILTER_ID"] = 0xF058;
    m_mapRegisters["F7M7_VALUE_SETTING"] = 0xF07C;

    m_mapRegisters["ADV_ACCESS_CTRL"] = 0x01000000;
    m_mapRegisters["ADV_ACCESS_CTRL+1"] = 0x01000004;

    m_mapRegisters["ADV_VERSION_INFO"] = 0x01000010;
    m_mapRegisters["ADV_VERSION_INFO+1"] = 0x01000014;
    m_mapRegisters["ADV_VERSION_INFO+2"] = 0x01000018;
    m_mapRegisters["ADV_VERSION_INFO+3"] = 0x0100001C;
    m_mapRegisters["ADV_FNC_INQ"] = 0x01000040;
    m_mapRegisters["ADV_FNC_INQ+1"] = 0x01000044;
    m_mapRegisters["ADV_FNC_INQ+2"] = 0x01000048;
    m_mapRegisters["ADV_FNC_INQ+3"] = 0x0100004C;
    m_mapRegisters["ADV_CAMSTATUS"] = 0x01000100;
    m_mapRegisters["ADV_MAX_RESOLUTION"] = 0x01000200;
    m_mapRegisters["ADV_TIMEBASE"] = 0x01000208;
    m_mapRegisters["ADV_EXTD_SHUTTER"] = 0x0100020C;
    m_mapRegisters["ADV_TESTPIX"] = 0x01000210;
    m_mapRegisters["ADV_SEQCTRL"] = 0x01000220;
    m_mapRegisters["ADV_SEQPARAM"] = 0x01000224;
    m_mapRegisters["ADV_SEQSTEP"] = 0x01000228;
    m_mapRegisters["ADV_LUTCTRL"] = 0x01000240;
    m_mapRegisters["ADV_LUTCTRL_MEM"] = 0x01000244;
    m_mapRegisters["ADV_LUTCTRL_INFO"] = 0x01000248;
    m_mapRegisters["ADV_SHADING"] = 0x01000250;
    m_mapRegisters["ADV_SHADING_MEM"] = 0x01000254;
    m_mapRegisters["ADV_SHADING_INFO"] = 0x01000258;
    m_mapRegisters["ADV_DEFERREDTRANS"] = 0x01000260;
    m_mapRegisters["(ADV_FRAMEINFO_OLD)"] = 0x01000270;
    m_mapRegisters["ADV_HDR_IBIS"] = 0x01000280;
    m_mapRegisters["ADV_HDR_IBIS+1"] = 0x01000284;
    m_mapRegisters["ADV_HDR_IBIS+2"] = 0x01000288;
    m_mapRegisters["ADV_HDR_IBIS+3"] = 0x0100028C;
    m_mapRegisters["ADV_HDR_MICRON"] = 0x01000280;
    m_mapRegisters["ADV_HDR_MICRON+1"] = 0x01000284;
    m_mapRegisters["ADV_DSNU_CORRECTION"] = 0x01000290;
    m_mapRegisters["ADV_BLEMISH_CORRECTION"] = 0x01000294;
    m_mapRegisters["ADV_DPCCTRL"] = 0x01000298;
    m_mapRegisters["ADV_DPCCTRL_MEM"] = 0x0100029C;
    m_mapRegisters["ADV_DPCCTRL_INFO"] = 0x010002A0;
    m_mapRegisters["ADV_HDR_PIKE"] = 0x010002B0;
    m_mapRegisters["ADV_HDR_PIKE+1"] = 0x010002B4;
    m_mapRegisters["ADV_IO_INP_CTRL"] = 0x01000300;
    m_mapRegisters["ADV_IO_INP_CTRL+1"] = 0x01000304;
    m_mapRegisters["ADV_IO_INP_CTRL+2"] = 0x01000308;
    m_mapRegisters["ADV_IO_INP_CTRL+3"] = 0x0100030C;
    m_mapRegisters["ADV_IO_OUTP_CTRL"] = 0x01000320;
    m_mapRegisters["ADV_IO_OUTP_CTRL+1"] = 0x01000324;
    m_mapRegisters["ADV_IO_OUTP_CTRL+2"] = 0x01000328;
    m_mapRegisters["ADV_IO_OUTP_CTRL+3"] = 0x0100032C;
    m_mapRegisters["ADV_IO_INTENA_DELAY"] = 0x01000340;
    m_mapRegisters["ADV_IO_DECODER"] = 0x01000350;
    m_mapRegisters["ADV_IO_DECODER+1"] = 0x01000354;
    m_mapRegisters["ADV_AUTOSHUTTER"] = 0x01000360;
    m_mapRegisters["ADV_AUTOSHUTTER+1"] = 0x01000364;
    m_mapRegisters["ADV_AUTOSHUTTER+2"] = 0x01000368;
    m_mapRegisters["ADV_AUTOGAIN"] = 0x01000370;
    m_mapRegisters["ADV_AUTOFNC_AOI"] = 0x01000390;
    m_mapRegisters["ADV_AUTOFNC_AOI+1"] = 0x01000394;
    m_mapRegisters["ADV_AUTOFNC_AOI+2"] = 0x01000398;
    m_mapRegisters["ADV_COLORCORRECTION"] = 0x010003A0;
    m_mapRegisters["ADV_TRIGGER_DLY"] = 0x01000400;
    m_mapRegisters["ADV_IMAGE_MIRROR"] = 0x01000410;
    m_mapRegisters["ADV_MISC_FEATURES"] = 0x01000410;
    m_mapRegisters["ADV_MISC_FEATURES+1"] = 0x01000414;
    m_mapRegisters["ADV_CHN_ADJ_GAIN"] = 0x01000420;
    m_mapRegisters["ADV_CHN_ADJ_GAIN+1"] = 0x01000424;
    m_mapRegisters["ADV_CHANNEL_ADJUST"] = 0x01000420;
    m_mapRegisters["ADV_CHN_ADJ_OFFSET"] = 0x01000430;
    m_mapRegisters["ADV_CHN_ADJ_OFFSET+1"] = 0x01000434;
    m_mapRegisters["ADV_SMEARREDUCTION"] = 0x01000440;
    m_mapRegisters["ADV_SOFTRESET"] = 0x01000510;
    m_mapRegisters["ADV_HIGHSNR"] = 0x01000520;
    m_mapRegisters["ADV_COLOR_ANTIALIASING"] = 0x01000530;
    m_mapRegisters["(ADV_TIMESTAMP_OLD)"] = 0x01000540;
    m_mapRegisters["ADV_USERSETS"] = 0x01000550;
    m_mapRegisters["ADV_MAX_ISOSIZE400"] = 0x01000560;
    m_mapRegisters["ADV_MAX_ISOSIZE800"] = 0x01000564;
    m_mapRegisters["ADV_MAX_ISOSIZE1600"] = 0x01000568;
    m_mapRegisters["ADV_PARAMUPDATEMODE"] = 0x01000570;
    m_mapRegisters["ADV_F7MODEMAPPING"] = 0x01000580;
    m_mapRegisters["ADV_LOW_NOISE_BINNING"] = 0x010005B0;
    m_mapRegisters["ADV_GLOB_RES_REL_SHUTTER"] = 0x010005C0;
    m_mapRegisters["ADV_TIMESTAMP"] = 0x01000600;
    m_mapRegisters["ADV_TIMESTAMP+1"] = 0x01000604;
    m_mapRegisters["ADV_FRAMEINFO"] = 0x01000610;
    m_mapRegisters["ADV_FRAMEINFO+1"] = 0x01000614;
    m_mapRegisters["ADV_TRGCOUNTER"] = 0x01000620;
    m_mapRegisters["ADV_TRGCOUNTER+1"] = 0x01000624;
    m_mapRegisters["ADV_SIS"] = 0x01000630;
    m_mapRegisters["ADV_SIS_USERVALUE"] = 0x01000634;
    m_mapRegisters["ADV_SW_FEATURE_CTRL"] = 0x01000640;
    m_mapRegisters["ADV_IO_OUTP_PWM_1"] = 0x01000800;
    m_mapRegisters["ADV_IO_OUTP_PWM_2"] = 0x01000808;
    m_mapRegisters["ADV_IO_OUTP_PWM_3"] = 0x01000810;
    m_mapRegisters["ADV_IO_OUTP_PWM_4"] = 0x01000818;
    m_mapRegisters["ADV_IO_INP_DEB_1"] = 0x01000840;
    m_mapRegisters["ADV_IO_INP_DEB_2"] = 0x01000850;
    m_mapRegisters["ADV_IO_INP_DEB_3"] = 0x01000860;
    m_mapRegisters["ADV_IO_INP_DEB_4"] = 0x01000870;
    m_mapRegisters["ADV_GAINREF_CTRL"] = 0x01002000;
    m_mapRegisters["ADV_GAINREF_1"] = 0x01002004;
    m_mapRegisters["ADV_GAINREF_2"] = 0x01002008;
    m_mapRegisters["ADV_WHITEBALANCE_INQ"] = 0x010080C0;
    m_mapRegisters["ADV_WHITEBALANCE+1"] = 0x010080C4;
    m_mapRegisters["ADV_WHITEBALANCE+2"] = 0x010080C8;
    m_mapRegisters["ADV_PARAMLIST_INFO"] = 0x01100000;
}

QMap<QString,uint32_t> RegisterMap::m_mapRegisters = QMap<QString,uint32_t>();
