/** \file smarttabsplitter.cpp
 *  \brief This file contains the implementation of the SmartTabSplitter class.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#include "smarttabsplitter.h"
#include "smarttabsplitterhandle.h"

SmartTabSplitter::SmartTabSplitter( QWidget * parent )
 : QSplitter( parent )
{
}


SmartTabSplitter::~SmartTabSplitter()
{
}


void SmartTabSplitter::setControlVisibility(bool bHidden)
{
	QList<int> nSizes = sizes();
	int nTotalSize = nSizes[0]+nSizes[1];
	if ( bHidden )
	{
		nSizes[0] = 0;
		nSizes[1] = nTotalSize - 0;
		setSizes( nSizes );
	}
	else
	{
		nSizes[0] = 250;
		nSizes[1] = nTotalSize - 250;
		setSizes( nSizes );
	}
}


QSplitterHandle *SmartTabSplitter::createHandle()
 {
     return new SmartTabSplitterHandle(orientation(), this);
 }

void SmartTabSplitter::moveSplitter(int pos, int index)
{
	if ( pos >= 120 )
	{
		QSplitter::moveSplitter( qMax(pos,220), index);
	}
	else
	{
		QSplitter::moveSplitter(0, index);
	}
}
